# Prime Number Generator

This program uses the "Sieve of Atkin" algorithm to sieve primes. It is an optimized version of the "Sieve of Eratosthenes". Although this program is written in Python, the "setup.py" file contains code to allow use with "Cython" which is a Python-to-C which allows it to achieve higher performance:

